/************************************************************************
*                                                                       *
*        Simple Desktop Display Manager Theme for UNSW Australia        *
*                   Copyright (C) 2016, John Zaitseff                   *
*                                                                       *
************************************************************************/

/*
  Author: John Zaitseff <J.Zaitseff@zap.org.au>
  $Id$

  The Simple Desktop Display Manager Theme for UNSW Australia provides a
  theme for SDDM that is suitable for the University of New South Wales,
  Australia.


  This program is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see http://www.gnu.org/licenses/.
*/


import QtQuick 2.0
import SddmComponents 2.0


Rectangle {
    id: mainContainer
    width: 1024
    height: 576

    LayoutMirroring.enabled: Qt.locale().textDirection == Qt.RightToLeft
    LayoutMirroring.childrenInherit: true

    TextConstants {
	id: textConstants
    }

    Connections {
	target: sddm

	onLoginSucceeded: {
	    errorMessage.color = "steelblue"
	    errorMessage.text = textConstants.loginSucceeded
	}

	onLoginFailed: {
	    errorMessage.color = "red"
	    errorMessage.text = textConstants.loginFailed
	}
    }

    Background {
	anchors.fill: parent
	source: config.background
	fillMode: Image.PreserveAspectCrop

	onStatusChanged: {
	    if (status == Image.Error && source != config.defaultBackground) {
		source = config.defaultBackground
	    }
	}
    }

    Rectangle {
	anchors.fill: parent
	color: "transparent"
	visible: primaryScreen

	Clock {
	    id: clock
	    anchors.margins: 5
	    anchors.top: parent.top
	    anchors.right: parent.right

	    color: "white"
	    timeFont.family: "Oxygen"
	}

	Image {
	    id: loginBox
	    anchors.centerIn: parent
	    width: Math.max(320, mainColumn.implicitWidth + 50)
	    height: Math.max(320, mainColumn.implicitHeight + 50)

	    source: "rectangle.png"

	    Column {
		id: mainColumn
		anchors.centerIn: parent
		spacing: 12

		Text {
		    anchors.horizontalCenter: parent.horizontalCenter
		    width: parent.width
		    height: text.implicitHeight
		    // text: textConstants.welcomeText.arg(sddm.hostName)
		    text: sddm.hostName
		    wrapMode: Text.WordWrap
		    font.pixelSize: 28
		    color: "black"
		    verticalAlignment: Text.AlignVCenter
		    horizontalAlignment: Text.AlignHCenter
		}

		Column {
		    width: parent.width
		    spacing: 4

		    Text {
			id: nameLabel
			width: parent.width
			text: textConstants.userName
			font.bold: true
			font.pixelSize: 12
		    }

		    TextBox {
			id: name
			width: parent.width
			height: 30
			// text: userModel.lastUser
			font.pixelSize: 14

			KeyNavigation.backtab: rebootButton
			KeyNavigation.tab: password

			Keys.onPressed: {
			    if (event.key === Qt.Key_Return || event.key === Qt.Key_Enter) {
				sddm.login(name.text, password.text, session.index)
				event.accepted = true
			    }
			}
		    }
		}

		Column {
		    width: parent.width
		    spacing: 4

		    Text {
			id: passwordLabel
			width: parent.width
			text: textConstants.password
			font.bold: true
			font.pixelSize: 12
		    }

		    PasswordBox {
			id: password
			width: parent.width
			height: 30
			font.pixelSize: 14

			KeyNavigation.backtab: name
			KeyNavigation.tab: session

			Keys.onPressed: {
			    if (event.key === Qt.Key_Return || event.key === Qt.Key_Enter) {
				sddm.login(name.text, password.text, session.index)
				event.accepted = true
			    }
			}
		    }
		}

		Row {
		    width: parent.width / 2
		    spacing: 4
		    z: 100

		    Column {
			width: parent.width * 1.3
			spacing: 4
			z: 100
			anchors.bottom: parent.bottom

			Text {
			    id: sessionLabel
			    width: parent.width
			    text: textConstants.session
			    wrapMode: TextEdit.WordWrap
			    font.bold: true
			    font.pixelSize: 12
			}

			ComboBox {
			    id: session
			    width: parent.width
			    height: 30
			    font.pixelSize: 14
			    arrowIcon: "down.png"

			    model: sessionModel
			    index: sessionModel.lastIndex

			    KeyNavigation.backtab: password
			    KeyNavigation.tab: layoutBox
			}
		    }

		    Column {
			width: parent.width * 0.7
			spacing: 4
			z: 101
			anchors.bottom: parent.bottom

			Text {
			    id: layoutLabel
			    width: parent.width
			    text: textConstants.layout
			    wrapMode: TextEdit.WordWrap
			    font.bold: true
			    font.pixelSize: 12
			}

			LayoutBox {
			    id: layoutBox
			    width: parent.width
			    height: 30
			    font.pixelSize: 14
			    arrowIcon: "down.png"

			    KeyNavigation.backtab: session
			    KeyNavigation.tab: loginButton
			}
		    }
		}

		Column {
		    width: parent.width

		    Text {
			id: errorMessage
			anchors.horizontalCenter: parent.horizontalCenter
			text: textConstants.prompt
			font.pixelSize: 12
		    }
		}

		Row {
		    spacing: 4
		    anchors.horizontalCenter: parent.horizontalCenter

		    property int buttonWidth: Math.max(loginButton.implicitWidth,
						       shutdownButton.implicitWidth,
						       rebootButton.implicitWidth,
						       80) + 8

		    Button {
			id: loginButton
			width: parent.buttonWidth
			text: textConstants.login

			onClicked: {
			    sddm.login(name.text, password.text, session.index)
			}

			KeyNavigation.backtab: layoutBox
			KeyNavigation.tab: shutdownButton
		    }

		    Button {
			id: shutdownButton
			width: parent.buttonWidth
			text: textConstants.shutdown

			onClicked: {
			    sddm.powerOff()
			}

			KeyNavigation.backtab: loginButton
			KeyNavigation.tab: rebootButton
		    }

		    Button {
			id: rebootButton
			width: parent.buttonWidth
			text: textConstants.reboot

			onClicked: {
			    sddm.reboot()
			}

			KeyNavigation.backtab: shutdownButton
			KeyNavigation.tab: name
		    }
		}
	    }
	}
    }

    Component.onCompleted: {
	if (name.text == "") {
	    name.focus = true
	} else {
	    password.focus = true
	}
    }
}
